@@ -180,6 +180,19 @@ def get_ecs_services(cluster_name):
         return services
 
 
+def get_ids_from_container_instances(cluster_name, container_instances):
+    ids = []
+
+    container_instances_description = ecs.describe_container_instances(
+        cluster=cluster_name, containerInstances=container_instances
+    )
+
+    for c in container_instances_description["containerInstances"]:
+        ids.append(c["ec2InstanceId"])
+
+    return ids
+
+
 def get_ips_from_container_instances(cluster_name, container_instances):
     instances_id = []
     ips = []
